==> openshift-model-machine-6.6.2-sources.jar: io/fabric8/openshift/api/model/machine/v1beta1/MachineSpecFluent.java <==
package io.fabric8.openshift.api.model.machine.v1beta1;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.Taint;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface MachineSpecFluent<A extends MachineSpecFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildLifecycleHooks instead.
   * @return The buildable object.
   */
  @Deprecated
  public LifecycleHooks getLifecycleHooks();
  public LifecycleHooks buildLifecycleHooks();
  public A withLifecycleHooks(LifecycleHooks lifecycleHooks);
  public Boolean hasLifecycleHooks();
  public MachineSpecFluent.LifecycleHooksNested<A> withNewLifecycleHooks();
  public MachineSpecFluent.LifecycleHooksNested<A> withNewLifecycleHooksLike(LifecycleHooks item);
  public MachineSpecFluent.LifecycleHooksNested<A> editLifecycleHooks();
  public MachineSpecFluent.LifecycleHooksNested<A> editOrNewLifecycleHooks();
  public MachineSpecFluent.LifecycleHooksNested<A> editOrNewLifecycleHooksLike(LifecycleHooks item);
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public MachineSpecFluent.MetadataNested<A> withNewMetadata();
  public MachineSpecFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public MachineSpecFluent.MetadataNested<A> editMetadata();
  public MachineSpecFluent.MetadataNested<A> editOrNewMetadata();
  public MachineSpecFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  public String getProviderID();
  public A withProviderID(String providerID);
  public Boolean hasProviderID();
  
  /**
   * This method has been deprecated, please use method buildProviderSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public ProviderSpec getProviderSpec();
  public ProviderSpec buildProviderSpec();
  public A withProviderSpec(ProviderSpec providerSpec);
  public Boolean hasProviderSpec();
  public MachineSpecFluent.ProviderSpecNested<A> withNewProviderSpec();
  public MachineSpecFluent.ProviderSpecNested<A> withNewProviderSpecLike(ProviderSpec item);
  public MachineSpecFluent.ProviderSpecNested<A> editProviderSpec();
  public MachineSpecFluent.ProviderSpecNested<A> editOrNewProviderSpec();
  public MachineSpecFluent.ProviderSpecNested<A> editOrNewProviderSpecLike(ProviderSpec item);
  public A addToTaints(Integer index,Taint item);
  public A setToTaints(Integer index,Taint item);
  public A addToTaints(io.fabric8.kubernetes.api.model.Taint... items);
  public A addAllToTaints(Collection<Taint> items);
  public A removeFromTaints(io.fabric8.kubernetes.api.model.Taint... items);
  public A removeAllFromTaints(Collection<Taint> items);
  public List<Taint> getTaints();
  public Taint getTaint(Integer index);
  public Taint getFirstTaint();
  public Taint getLastTaint();
  public Taint getMatchingTaint(Predicate<Taint> predicate);
  public Boolean hasMatchingTaint(Predicate<Taint> predicate);
  public A withTaints(List<Taint> taints);
  public A withTaints(io.fabric8.kubernetes.api.model.Taint... taints);
  public Boolean hasTaints();
  public A addNewTaint(String effect,String key,String timeAdded,String value);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface LifecycleHooksNested<N> extends Nested<N>,LifecycleHooksFluent<MachineSpecFluent.LifecycleHooksNested<N>>{
    public N and();
    public N endLifecycleHooks();
    
  }
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<MachineSpecFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface ProviderSpecNested<N> extends Nested<N>,ProviderSpecFluent<MachineSpecFluent.ProviderSpecNested<N>>{
    public N and();
    public N endProviderSpec();
    
  }
  
}

==> openshift-model-machine-6.7.2-sources.jar: io/fabric8/openshift/api/model/machine/v1beta1/MachineSpecFluent.java <==
package io.fabric8.openshift.api.model.machine.v1beta1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.Taint;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface MachineSpecFluent<A extends MachineSpecFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildLifecycleHooks instead.
   * @return The buildable object.
   */
  @Deprecated
  public LifecycleHooks getLifecycleHooks();
  public LifecycleHooks buildLifecycleHooks();
  public A withLifecycleHooks(LifecycleHooks lifecycleHooks);
  public Boolean hasLifecycleHooks();
  public MachineSpecFluent.LifecycleHooksNested<A> withNewLifecycleHooks();
  public MachineSpecFluent.LifecycleHooksNested<A> withNewLifecycleHooksLike(LifecycleHooks item);
  public MachineSpecFluent.LifecycleHooksNested<A> editLifecycleHooks();
  public MachineSpecFluent.LifecycleHooksNested<A> editOrNewLifecycleHooks();
  public MachineSpecFluent.LifecycleHooksNested<A> editOrNewLifecycleHooksLike(LifecycleHooks item);
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public MachineSpecFluent.MetadataNested<A> withNewMetadata();
  public MachineSpecFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public MachineSpecFluent.MetadataNested<A> editMetadata();
  public MachineSpecFluent.MetadataNested<A> editOrNewMetadata();
  public MachineSpecFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  public String getProviderID();
  public A withProviderID(String providerID);
  public Boolean hasProviderID();
  
  /**
   * This method has been deprecated, please use method buildProviderSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public ProviderSpec getProviderSpec();
  public ProviderSpec buildProviderSpec();
  public A withProviderSpec(ProviderSpec providerSpec);
  public Boolean hasProviderSpec();
  public MachineSpecFluent.ProviderSpecNested<A> withNewProviderSpec();
  public MachineSpecFluent.ProviderSpecNested<A> withNewProviderSpecLike(ProviderSpec item);
  public MachineSpecFluent.ProviderSpecNested<A> editProviderSpec();
  public MachineSpecFluent.ProviderSpecNested<A> editOrNewProviderSpec();
  public MachineSpecFluent.ProviderSpecNested<A> editOrNewProviderSpecLike(ProviderSpec item);
  public A addToTaints(int index,Taint item);
  public A setToTaints(int index,Taint item);
  public A addToTaints(io.fabric8.kubernetes.api.model.Taint... items);
  public A addAllToTaints(Collection<Taint> items);
  public A removeFromTaints(io.fabric8.kubernetes.api.model.Taint... items);
  public A removeAllFromTaints(Collection<Taint> items);
  public List<Taint> getTaints();
  public Taint getTaint(int index);
  public Taint getFirstTaint();
  public Taint getLastTaint();
  public Taint getMatchingTaint(Predicate<Taint> predicate);
  public Boolean hasMatchingTaint(Predicate<Taint> predicate);
  public A withTaints(List<Taint> taints);
  public A withTaints(io.fabric8.kubernetes.api.model.Taint... taints);
  public Boolean hasTaints();
  public A addNewTaint(String effect,String key,String timeAdded,String value);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface LifecycleHooksNested<N> extends Nested<N>,LifecycleHooksFluent<MachineSpecFluent.LifecycleHooksNested<N>>{
    public N and();
    public N endLifecycleHooks();
    
  }
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<MachineSpecFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface ProviderSpecNested<N> extends Nested<N>,ProviderSpecFluent<MachineSpecFluent.ProviderSpecNested<N>>{
    public N and();
    public N endProviderSpec();
    
  }
  
}
